@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclPosixStr.c,v 1.12 2005/11/07 15:16:03 dkf Exp $
+ * RCS: @(#) $Id: tclPosixStr.c,v 1.12.10.1 2009/03/15 15:38:19 dkf Exp $
  */
 
 #include "tclInt.h"
@@ -1038,6 +1038,9 @@ Tcl_SignalId(
 #endif
 #ifdef SIGXFSZ
     case SIGXFSZ: return "SIGXFSZ";
+#endif
+#if defined(SIGINFO) && (!defined(SIGPWR) || (SIGINFO != SIGPWR))
+    case SIGINFO: return "SIGINFO";
 #endif
     }
     return "unknown signal";
@@ -1169,6 +1172,9 @@ Tcl_SignalMsg(
 #endif
 #ifdef SIGXFSZ
     case SIGXFSZ: return "exceeded file size limit";
+#endif
+#if defined(SIGINFO) && (!defined(SIGPWR) || (SIGINFO != SIGPWR))
+    case SIGINFO: return "information request";
 #endif
     }
     return "unknown signal";
