@@ -4,58 +4,70 @@
  *	This file implements functions that inspect CFBundle structures on
  *	MacOS X.
  *
- * Copyright 2001, Apple Computer, Inc.
- * Copyright (c) 2003-2007 Daniel A. Steffen <das@users.sourceforge.net>
+ * Copyright 2001-2009, Apple Inc.
+ * Copyright (c) 2003-2009 Daniel A. Steffen <das@users.sourceforge.net>
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- *	The following terms apply to all files originating from Apple
- *	Computer, Inc. ("Apple") and associated with the software unless
- *	explicitly disclaimed in individual files.
- *
- *	Apple hereby grants permission to use, copy, modify, distribute, and
- *	license this software and its documentation for any purpose, provided
- *	that existing copyright notices are retained in all copies and that
- *	this notice is included verbatim in any distributions. No written
- *	agreement, license, or royalty fee is required for any of the
- *	authorized uses. Modifications to this software may be copyrighted by
- *	their authors and need not follow the licensing terms described here,
- *	provided that the new terms are clearly indicated on the first page of
- *	each file where they apply.
- *
- *	IN NO EVENT SHALL APPLE, THE AUTHORS OR DISTRIBUTORS OF THE SOFTWARE
- *	BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR
- *	CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS SOFTWARE, ITS
- *	DOCUMENTATION, OR ANY DERIVATIVES THEREOF, EVEN IF APPLE OR THE
- *	AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. APPLE,
- *	THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
- *	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
- *	MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
- *	NON-INFRINGEMENT. THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, AND
- *	APPLE,THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
- *	MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
- *
- *	GOVERNMENT USE: If you are acquiring this software on behalf of the
- *	U.S. government, the Government shall have only "Restricted Rights" in
- *	the software and related documentation as defined in the Federal
- *	Acquisition Regulations (FARs) in Clause 52.227.19 (c) (2). If you are
- *	acquiring the software on behalf of the Department of Defense, the
- *	software shall be classified as "Commercial Computer Software" and the
- *	Government shall have only "Restricted Rights" as defined in Clause
- *	252.227-7013 (c) (1) of DFARs. Notwithstanding the foregoing, the
- *	authors grant the U.S. Government and others acting in its behalf
- *	permission to use and distribute the software in accordance with the
- *	terms specified in this license.
- *
- * RCS: @(#) $Id: tclMacOSXBundle.c,v 1.11.4.1 2008/12/07 16:39:32 das Exp $
+ * RCS: @(#) $Id: tclMacOSXBundle.c,v 1.11.4.3 2009/04/14 00:55:34 das Exp $
  */
 
 #include "tclPort.h"
 
 #ifdef HAVE_COREFOUNDATION
 #include <CoreFoundation/CoreFoundation.h>
+
+#ifndef TCL_DYLD_USE_DLFCN
+/*
+ * Use preferred dlfcn API on 10.4 and later
+ */
+#   if !defined(NO_DLFCN_H) && MAC_OS_X_VERSION_MAX_ALLOWED >= 1040
+#	define TCL_DYLD_USE_DLFCN 1
+#   else
+#	define TCL_DYLD_USE_DLFCN 0
+#   endif
+#endif
+
+#ifndef TCL_DYLD_USE_NSMODULE
+/*
+ * Use deprecated NSModule API only to support 10.3 and earlier:
+ */
+#   if MAC_OS_X_VERSION_MIN_REQUIRED < 1040
+#	define TCL_DYLD_USE_NSMODULE 1
+#   else
+#	define TCL_DYLD_USE_NSMODULE 0
+#   endif
+#endif
+
+#if TCL_DYLD_USE_DLFCN
+#include <dlfcn.h>
+#if defined(HAVE_WEAK_IMPORT) && MAC_OS_X_VERSION_MIN_REQUIRED < 1040
+/*
+ * Support for weakly importing dlfcn API.
+ */
+extern void *dlsym(void *handle, const char *symbol) WEAK_IMPORT_ATTRIBUTE;
+extern char *dlerror(void) WEAK_IMPORT_ATTRIBUTE;
+#endif
+#endif
+
+#if TCL_DYLD_USE_NSMODULE
 #include <mach-o/dyld.h>
+#endif
+
+#if TCL_DYLD_USE_DLFCN && MAC_OS_X_VERSION_MIN_REQUIRED < 1040
+MODULE_SCOPE long tclMacOSXDarwinRelease;
+#endif
+
+#ifdef TCL_DEBUG_LOAD
+#define TclLoadDbgMsg(m, ...) do { \
+	    fprintf(stderr, "%s:%d: %s(): " m ".\n", \
+	    strrchr(__FILE__, '/')+1, __LINE__, __func__, ##__VA_ARGS__); \
+	} while (0)
+#else
+#define TclLoadDbgMsg(m, ...)
+#endif
+
 #endif /* HAVE_COREFOUNDATION */
 
 /*
@@ -192,15 +204,36 @@ Tcl_MacOSXOpenVersionedBundleResources(
 	    static short (*openresourcemap)(CFBundleRef) = NULL;
 
 	    if (!initialized) {
-		NSSymbol nsSymbol = NULL;
-		if (NSIsSymbolNameDefinedWithHint(
-			"_CFBundleOpenBundleResourceMap", "CoreFoundation")) {
-		    nsSymbol = NSLookupAndBindSymbolWithHint(
-			    "_CFBundleOpenBundleResourceMap","CoreFoundation");
-		    if (nsSymbol) {
-			openresourcemap = NSAddressOfSymbol(nsSymbol);
+#if TCL_DYLD_USE_DLFCN
+#if MAC_OS_X_VERSION_MIN_REQUIRED < 1040
+		if (tclMacOSXDarwinRelease >= 8)
+#endif
+		{
+		    const char *errMsg = nil;
+		    openresourcemap = dlsym(RTLD_NEXT,
+			    "CFBundleOpenBundleResourceMap");
+		    if (!openresourcemap) {
+			errMsg = dlerror();
+			TclLoadDbgMsg("dlsym() failed: %s", errMsg);
 		    }
 		}
+		if (!openresourcemap)
+#endif
+		{
+#if TCL_DYLD_USE_NSMODULE
+		    NSSymbol nsSymbol = NULL;
+		    if (NSIsSymbolNameDefinedWithHint(
+			    "_CFBundleOpenBundleResourceMap",
+			    "CoreFoundation")) {
+			nsSymbol = NSLookupAndBindSymbolWithHint(
+				"_CFBundleOpenBundleResourceMap",
+				"CoreFoundation");
+			if (nsSymbol) {
+			    openresourcemap = NSAddressOfSymbol(nsSymbol);
+			}
+		    }
+#endif
+		}
 		initialized = TRUE;
 	    }
 
