@@ -1,23 +1,21 @@
-/* 
+/*
  * tclWinError.c --
  *
- *	This file contains code for converting from Win32 errors to
- *	errno errors.
+ *	This file contains code for converting from Win32 errors to errno
+ *	errors.
  *
  * Copyright (c) 1995-1996 by Sun Microsystems, Inc.
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ * See the file "license.terms" for information on usage and redistribution of
+ * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclWinError.c,v 1.2 1998/09/14 18:40:19 stanton Exp $
+ * RCS: @(#) $Id: tclWinError.c,v 1.7 2005/11/04 00:06:50 dkf Exp $
  */
 
 #include "tclInt.h"
-#include "tclPort.h"
 
 /*
- * The following table contains the mapping from Win32 errors to
- * errno errors.
+ * The following table contains the mapping from Win32 errors to errno errors.
  */
 
 static char errorTable[] = {
@@ -148,11 +146,11 @@ static char errorTable[] = {
     EINVAL,	/* 124 */
     EINVAL,	/* 125 */
     EINVAL,	/* 126 */
-    ESRCH,	/* ERROR_PROC_NOT_FOUND		127 */
+    EINVAL,	/* ERROR_PROC_NOT_FOUND		127 */
     ECHILD,	/* ERROR_WAIT_NO_CHILDREN	128 */
     ECHILD,	/* ERROR_CHILD_NOT_COMPLETE	129 */
     EBADF,	/* ERROR_DIRECT_ACCESS_HANDLE	130 */
-    EINVAL,	/* 131 */
+    EINVAL,	/* ERROR_NEGATIVE_SEEK		131 */
     ESPIPE,	/* ERROR_SEEK_ON_DEVICE		132 */
     EINVAL,	/* 133 */
     EINVAL,	/* 134 */
@@ -355,8 +353,8 @@ static int wsaErrorTable[] = {
  */
 
 void
-TclWinConvertError(errCode)
-    DWORD errCode;		/* Win32 error code. */
+TclWinConvertError(
+    DWORD errCode)		/* Win32 error code. */
 {
     if (errCode >= tableLen) {
 	Tcl_SetErrno(EINVAL);
@@ -382,8 +380,8 @@ TclWinConvertError(errCode)
  */
 
 void
-TclWinConvertWSAError(errCode)
-    DWORD errCode;		/* Win32 error code. */
+TclWinConvertWSAError(
+    DWORD errCode)		/* Win32 error code. */
 {
     if ((errCode >= WSAEWOULDBLOCK) && (errCode <= WSAEREMOTE)) {
 	Tcl_SetErrno(wsaErrorTable[errCode - WSAEWOULDBLOCK]);
